package main

import (
	"cs"
	"f5"
)

type Player struct {
	cs.MsgHandlerImpl
	socket    f5.WspCliConn
	accountId string
	sessionId string
}

func (p *Player) CMSearchFriends(hdr *f5.MsgHdr, msg *cs.CMSearchFriend) {
	rspMsg := new(cs.SMSearchFriend)
	//rspMsg := &cs.SMSearchFriend{}
	listUsers := friendMgr.searchUsers(msg.GetSearchKeyword())
	for _, u := range listUsers {
		friend := &cs.MFFriend{
			AccountId: &u.AccountId,
			Username:  &u.Username,
		}
		rspMsg.Friends = append(rspMsg.Friends, friend)
	}
	wspListener.sendProxyMsg(hdr.Conn, hdr.SocketHandle, rspMsg)
}

// CMListPendingFriendRequest 等待验证的好友请求
func (p *Player) CMListPendingFriendRequest(hdr *f5.MsgHdr, msg *cs.CMListPendingFriendRequest) {
	rspMsg := &cs.SMListPendingFriendRequest{}
	accountId := p.accountId
	for accountId, flag := range friendMgr.pendingReqs[accountId] {
		row := &cs.MFPendingFriendRequest{
			AccountId: &accountId,
			Flag:      &flag,
		}
		rspMsg.PendingFriendRequest = append(rspMsg.PendingFriendRequest, row)
	}
	f5.GetSysLog().Info("CMListPendingFriendRequest requests count:%d\n", len(rspMsg.PendingFriendRequest))
	wspListener.sendProxyMsg(hdr.Conn, hdr.SocketHandle, rspMsg)
}

func (p *Player) CMAddFriendRequest(hdr *f5.MsgHdr, msg *cs.CMAddFriendRequest) {
	rspMsg := &cs.SMAddFriendRequest{}

	user1Id := p.accountId
	user2Id := msg.GetTargetAccountId()
	err := friendMgr.addFriendRequest(user1Id, user2Id)
	if err != nil {
		reason := err.Error()
		rspMsg.Reason = &reason
		wspListener.sendProxyMsg(hdr.Conn, hdr.SocketHandle, rspMsg)
		f5.GetSysLog().Info("CMAddFriendRequest: reason:%s, params: %s or %s\n", reason, user1Id, user2Id)
		return
	}

	status := "pending"
	rspMsg.Status = &status
	wspListener.sendProxyMsg(hdr.Conn, hdr.SocketHandle, rspMsg)
}

func (p *Player) CMAcceptFriendRequest(hdr *f5.MsgHdr, msg *cs.CMAcceptFriendRequest) {
	rspMsg := &cs.SMAcceptFriendRequest{}

	user1Id := p.accountId
	user2Id := msg.GetTargetAccountId()
	err := friendMgr.acceptFriendRequest(user1Id, user2Id)
	if err != nil {
		reason := err.Error()
		rspMsg.Reason = &reason
		wspListener.sendProxyMsg(hdr.Conn, hdr.SocketHandle, rspMsg)
		f5.GetSysLog().Info("CMAcceptFriendRequest: reason:%s, params: %s or %s\n", reason, user1Id, user2Id)
		return
	}

	status := "approved"
	rspMsg.Status = &status
	wspListener.sendProxyMsg(hdr.Conn, hdr.SocketHandle, rspMsg)
}

func (p *Player) CMListFriend(hdr *f5.MsgHdr, msg *cs.CMListFriend) {
	rspMsg := &cs.SMListFriend{}
	accountId := p.accountId
	for _, friendship := range friendMgr.friendships[accountId] {
		if friendship.User1.AccountId != accountId {
			friend := &cs.MFFriend{
				AccountId: &friendship.User1.AccountId,
				Username:  &friendship.User1.Username,
			}
			rspMsg.Friends = append(rspMsg.Friends, friend)
		} else {
			friend := &cs.MFFriend{
				AccountId: &friendship.User2.AccountId,
				Username:  &friendship.User2.Username,
			}
			rspMsg.Friends = append(rspMsg.Friends, friend)
		}
	}
	f5.GetSysLog().Info("CMListFriend friends count:%d\n", len(rspMsg.Friends))
	wspListener.sendProxyMsg(hdr.Conn, hdr.SocketHandle, rspMsg)
}

//func (fm *Player) FillFriend(rspMsg) {
//	//
//}
